pu.intranet.content
===============

PythonUnited Intranet Content module
This module provides some views and JavaScript to support inline editing of
content. The main functionality is for adding, removing and editing objects
without completely refreshing the page. This is done using JSON calls and
modal windows. This heavily relies on Bootstrap modal stuff.
